/* Copyright 2002 by Jos Visser <josv@osp.nl>
 * All rights reserved
 *
 * Distribute freely, except: don't remove my name from the source or
 * documentation (don't take credit for my work), mark your changes (don't
 * get me blamed for your possible bugs), don't alter or remove this
 * notice.  May be sold if buildable source is provided to buyer.  No
 * warrantee of any kind, express or implied, is included with this
 * software; use at your own risk, responsibility for damages (if any) to
 * anyone resulting from the use of this software rests entirely with the
 * user.
 *
 */

#if !defined(lint) && !defined(LINT)
static char rcsid[] = "$Id: cluster.c,v 1.0 2002/02/03 08:25:00 josv Exp $";
#endif

#include "cron.h"

#include <sys/stat.h>

#define FLAGFILE	"clustercron.auth"

static void 
error(char *file, char *msg) 
{
	fprintf(stderr,"%s: %s\n",file,msg);
	exit(ERROR_EXIT);
}

static void
check_crondir()
{
	struct stat	sb;
	int		len;
	char		*buf;

	if (stat(crondir,&sb)<0) {
		perror(crondir);
		exit(ERROR_EXIT);
	}

	if (!S_ISDIR(sb.st_mode)) error(crondir,"Must be a directory");
	if (sb.st_uid!=ROOT_UID) error(crondir,"Must be owned by root");
	if (sb.st_mode&022) error(crondir,"Must no be writable by anyone else but root");

	len=strlen(crondir)+strlen(FLAGFILE)+2;
	buf=(char *)malloc(len);
	sprintf(buf,"%s/%s",crondir,FLAGFILE);

	if (stat(buf,&sb)<0) {
		perror(buf);
		exit(ERROR_EXIT);
	}

	if (S_ISDIR(sb.st_mode)) error(buf,"Must not be a directory");
	if (sb.st_uid!=ROOT_UID) error(buf,"Must be owned by root");
}

void 
get_crondir()
{
	if (!crondir) crondir=getenv("CRONDIR");

	if (!crondir) {
#ifdef CLUSTER_CRON
		fputs("Cluster cron directory not set\n",stderr);
		fputs("Use -d or set the CRONDIR environment variable\n",stderr);
		exit(ERROR_EXIT);
#else
		crondir=CRONDIR;
#endif
	}

#ifdef CLUSTER_CRON
	check_crondir();
#endif
}
